coherence.upnp.core.soap_lite (module) — Cohen3 0.8.0 documentation

# coherence.upnp.core.soap_lite (module)

## SOAP-lite

Some simple functions to implement the SOAP messages needed by UPnP with ElementTree.

Note

Inspired by ElementSOAP.py

`build_soap_error`(status, description='without words', pretty_print=True)

  Builds an UPnP SOAP error message.

`build_soap_call`(method, arguments, ns=None, is_response=False, pretty_print=True)

  Create a shell for a SOAP request or response element:

  - set method to none to omit the method element and add the arguments directly to the body (for an error msg)
  - arguments can be a dict or an etree.Element